from django.forms.fields import CharField


class TruncatedCharField(CharField):
    def to_python(self, value):
        return super().to_python(value)[: self.max_length]


class CharToForeignKeyId(CharField):
    def __init__(self, *args, **kwargs):
        try:
            model = kwargs.pop('model')
            dbfield = kwargs.pop('dbfield')
        except KeyError:
            raise NotImplementedError("model and dbfield kwargs is required")
        self.mtx = dict(model.objects.values_list(dbfield, 'id'))
        super().__init__(*args, **kwargs)

    def to_python(self, value):
        value = super().to_python(value)
        value = self.mtx.get(value, None)
        if value is not None:
            return str(value)
        return None


class CharToChar(CharField):
    def __init__(self, *args, **kwargs):
        self.func = kwargs.pop('func', lambda x: x)
        super().__init__(*args, **kwargs)

    def to_python(self, value):
        value = self.func(super().to_python(value))
        if value is not None:
            return str(value)
        return None
